import { WTCGLRenderingContext, WTCGLUniformValue, WTCGLActiveInfo } from '../types';
import { Program } from './Program';
declare type Kind = 'int' | 'float' | 'boolean' | 'texture' | 'texture_array' | 'float_vec2' | 'float_vec3' | 'float_vec4' | 'int_vec2' | 'int_vec3' | 'int_vec4' | 'mat2' | 'mat3' | 'mat4';
/**
 * A uniform is just a basic container for simple uniform information.
 */
declare class Uniform {
    /**
     * The uniform name. Currently unused, but for future use in auto-parsing name
     */
    name: string;
    /**
     * The uniform value.
     */
    value: WTCGLUniformValue;
    /**
     * The uniform kind. Currently unused but useful in future for testing against supplied bind type.
     */
    kind: Kind;
    /**
     * Create a unform object
     * @param __namedParameters
     * @param name - The name of the uniform.
     * @param value - The value for the uniform.
     * @param kind - The type of uniform.
     */
    constructor({ name, value, kind }?: {
        name?: string;
        value?: WTCGLUniformValue;
        kind?: Kind;
    });
    /**
     * Set the uniform in the stated program.
     * @param gl - The WTCGL rendering context object.
     * @param type - A GLEnum representing the passed uniform type.
     * @param location - The uniform location (just an address to a uniform in program space)
     * @param value - The value of the uniform
     */
    setUniform(gl: WTCGLRenderingContext, type: GLenum, location: WebGLUniformLocation, value?: WTCGLUniformValue): void;
    /**
     * Binds the uniform to the program.
     * @param program - The program to which to bind the uniform.
     * @param location - A flag representing the uniform's location in memory.
     * @param activeUniform - Representes an extention of the standard Web GL active info for uniform.
     */
    bind(program: Program, location: WebGLUniformLocation, activeUniform: WTCGLActiveInfo): void;
}
export { Uniform };
